@@ -279,6 +279,7 @@ class PinGroup(object):
     def net_name(self):
         return self._edb_pin_group.GetNet().GetName()
 
+    @pyaedt_function_handler()
     def _create_terminal(self, is_reference=False):
         pg_term = self._edb_pin_group.GetPinGroupTerminal()
         pin_group_net = self._edb_pin_group.GetNet()
@@ -295,6 +296,7 @@ class PinGroup(object):
         else:
             return pg_term
 
+    @pyaedt_function_handler()
     def create_current_source_terminal(self, magnitude=1, phase=0):
         terminal = self._create_terminal()
         terminal.SetBoundaryType(self._pedb.edb.Cell.Terminal.BoundaryType.kCurrentSource)
@@ -302,6 +304,7 @@ class PinGroup(object):
         terminal.SetSourcePhase(self._pedb.edb.Utility.Value(phase))
         return terminal
 
+    @pyaedt_function_handler()
     def create_voltage_source_terminal(self, magnitude=1, phase=0):
         terminal = self._create_terminal()
         terminal.SetBoundaryType(self._pedb.edb.Cell.Terminal.BoundaryType.kVoltageSource)
@@ -309,6 +312,7 @@ class PinGroup(object):
         terminal.SetSourcePhase(self._pedb.edb.Utility.Value(phase))
         return terminal
 
+    @pyaedt_function_handler()
     def create_port_terminal(self, impedance=50):
         terminal = self._create_terminal()
         terminal.SetBoundaryType(self._pedb.edb.Cell.Terminal.BoundaryType.PortBoundary)
@@ -316,6 +320,20 @@ class PinGroup(object):
         terminal.SetIsCircuitPort(True)
         return terminal
 
+    @pyaedt_function_handler()
+    def delete(self):
+        """Delete active pin group.
+
+        Returns
+        -------
+        bool
+
+        """
+        terminals = self._edb_pin_group.GetPinGroupTerminal()
+        self._edb_pin_group.Delete()
+        terminals.Delete()
+        return True
+
 
 class CircuitPort(Source, object):
     """Manages a circuit port."""
@@ -770,7 +788,7 @@ class ExcitationPorts(CommonExcitation):
                 prim_shape_data = primitive.GetPolygonData()
                 if prim_shape_data.PointInPolygon(shape_pd):
                     return EDBPrimitives(primitive, self._pedb)
-        for vias in self._pedb.core_padstack.padstack_instances.values():
+        for vias in self._pedb.core_padstack.instances.values():
             if layer_name in vias.layer_range_names:
                 plane = self._pedb.core_primitives.Shape(
                     "rectangle", pointA=vias.position, pointB=vias.padstack_definition.bounding_box[1]
@@ -902,17 +920,17 @@ class ExcitationProbes(CommonExcitation):
         CommonExcitation.__init__(self, pedb, edb_terminal)
 
 
-class ExcitationDifferential:
-    """Manages differential excitation properties."""
+class ExcitationBundle:
+    """Manages multi terminal excitation properties."""
 
-    def __init__(self, pedb, edb_boundle_terminal):
+    def __init__(self, pedb, edb_bundle_terminal):
         self._pedb = pedb
-        self._edb_boundle_terminal = edb_boundle_terminal
+        self._edb_bundle_terminal = edb_bundle_terminal
 
     @property
     def name(self):
         """Port Name."""
-        return self._edb_boundle_terminal.GetName()
+        return self._edb_bundle_terminal.GetName()
 
     @property
     def edb(self):  # pragma: no cover
@@ -922,9 +940,16 @@ class ExcitationDifferential:
     @property
     def terminals(self):
         """Get terminals belonging to this excitation."""
-        return {i.GetName(): ExcitationPorts(self._pedb, i) for i in list(self.edb_boundle_terminal.GetTerminals())}
+        return {i.GetName(): ExcitationPorts(self._pedb, i) for i in list(self._edb_bundle_terminal.GetTerminals())}
 
     @property
     def reference_net_name(self):
         """Reference Name. Not applicable to Differential pairs."""
         return
+
+
+class ExcitationDifferential(ExcitationBundle):
+    """Manages differential excitation properties."""
+
+    def __init__(self, pedb, edb_boundle_terminal):
+        ExcitationBundle.__init__(self, pedb, edb_boundle_terminal)
