@@ -68,21 +68,23 @@ Parallel to this file, an xaml file should be present in the same directory.
 >>> if __name__ == '__main__':
 >>>     launch(__file__, specified_version="2021.2", new_desktop_session=False, autosave=False)
 """
+from datetime import datetime
 import json
 import os
 import shutil
 import sys
-from datetime import datetime
 from zipfile import ZIP_DEFLATED
 from zipfile import ZipFile
 
-import pyaedt.edb_core.edb_data.simulation_configuration
 from pyaedt import is_ironpython
+from pyaedt import is_linux
+from pyaedt import is_windows
 from pyaedt.desktop import Desktop
+import pyaedt.edb_core.edb_data.simulation_configuration
 from pyaedt.generic.clr_module import _clr
 from pyaedt.generic.general_methods import pyaedt_function_handler
 
-if os.name == "posix" and is_ironpython:
+if is_linux and is_ironpython:
     import subprocessdotnet as subprocess
 else:
     import subprocess
@@ -1335,8 +1337,7 @@ class WPFToolkit(Window):
     @pyaedt_function_handler()
     def open_explorer(self, sender, e):
         """Opens a windows explorer window pointing to the selected path in the sender control."""
-        os_type = os.name
-        if os_type == "nt":
+        if is_windows:
             selected_path = os.path.normpath(sender.Text)
             if os.path.exists(selected_path):
                 os_command_string = r'explorer "{}"'.format(selected_path)
