@@ -258,7 +258,8 @@ class Object3d(object):
 
     @pyaedt_function_handler()
     def export_image(self, file_path=None):
-        """Export the model to path.
+        """Export the current object to a specified file path.
+
 
         .. note::
            Works from AEDT 2021.2 in CPython only. PyVista has to be installed.
@@ -266,7 +267,9 @@ class Object3d(object):
         Parameters
         ----------
         file_path : str, optional
-            File name with full path. If `None` Project directory will be used.
+            File name with full path. If `None` the exported image will be a ``png`` file that
+            will be saved in ``working_directory``.
+            To access the ``working_directory`` the use ``app.working_directory`` property.
 
         Returns
         -------
@@ -1362,7 +1365,7 @@ class Object3d(object):
 
         Returns
         -------
-        pyaedt.modeler.object3d.Object3d
+        :class:`pyaedt.modeler.cad.object3d.Object3d`
            Object 3D object.
 
         References
@@ -1388,7 +1391,7 @@ class Object3d(object):
 
         Returns
         -------
-        :class:`pyaedt.modeler.object3d.Object3d`
+        :class:`pyaedt.modeler.cad.object3d.Object3d`
             Retrieve the resulting 3D Object when succeeded.
 
         References
@@ -1441,7 +1444,7 @@ class Object3d(object):
 
         Returns
         -------
-        pyaedt.modeler.Object3d.Object3d, bool
+        :class:`pyaedt.modeler.cad.object3d.Object3d`
             3D object.
             ``False`` when failed.
 
@@ -1460,7 +1463,7 @@ class Object3d(object):
 
         Parameters
         ----------
-        cs_axis
+        cs_axis : int
             Coordinate system axis or the Application.CoordinateSystemAxis object.
         angle : float, optional
             Angle of rotation. The units, defined by ``unit``, can be either
@@ -1471,9 +1474,8 @@ class Object3d(object):
 
         Returns
         -------
-        pyaedt.modeler.Object3d.Object3d, bool
-            3D object.
-            ``False`` when failed.
+        :class:`pyaedt.modeler.cad.object3d.Object3d`
+            3D object. ``False`` when failed.
 
         References
         ----------
@@ -1498,7 +1500,7 @@ class Object3d(object):
 
         Returns
         -------
-        pyaedt.modeler.Object3d.Object3d, bool
+        :class:`pyaedt.modeler.cad.object3d.Object3d`
             3D object.
             ``False`` when failed.
 
@@ -1526,7 +1528,7 @@ class Object3d(object):
 
         Returns
         -------
-        list
+        list of :class:`pyaedt.modeler.cad.object3d.Object3d`
             List of names of the newly added objects.
 
         References
@@ -1555,7 +1557,7 @@ class Object3d(object):
 
         Returns
         -------
-        list
+        list of :class:`pyaedt.modeler.cad.object3d.Object3d`
             List of names of the newly added objects.
 
         References
@@ -1576,7 +1578,7 @@ class Object3d(object):
 
         Returns
         -------
-        pyaedt.modeler.object3d.Object3d
+        :class:`pyaedt.modeler.cad.object3d.Object3d`
             3D object.
 
         References
@@ -1639,7 +1641,7 @@ class Object3d(object):
 
         Returns
         -------
-        pyaedt.modeler.object3d.Object3d
+        :class:`pyaedt.modeler.cad.object3d.Object3d`
             Swept object.
 
         References
@@ -1668,7 +1670,7 @@ class Object3d(object):
 
         Returns
         -------
-        pyaedt.modeler.object3d.Object3d
+        :class:`pyaedt.modeler.cad.object3d.Object3d`
             Swept object.
 
         References
@@ -1695,7 +1697,7 @@ class Object3d(object):
 
         Returns
         -------
-        pyaedt.modeler.object3d.Object3d
+        :class:`pyaedt.modeler.cad.object3d.Object3d`
             3D object.
 
         References
@@ -1713,7 +1715,7 @@ class Object3d(object):
 
         Returns
         -------
-        pyaedt.modeler.object3d.Object3d
+        :class:`pyaedt.modeler.cad.object3d.Object3d`
             3D object that was added.
 
         References
@@ -1742,7 +1744,7 @@ class Object3d(object):
 
         Returns
         -------
-        pyaedt.modeler.object3d.Object3d
+        :class:`pyaedt.modeler.cad.object3d.Object3d`
             Modified 3D object following the subtraction.
 
         References
