@@ -61,7 +61,7 @@ class Modeler3D(GeometryModeler, Primitives3D, object):
         self,
         component_file,
         component_name=None,
-        variables_to_include=[],
+        variables_to_include=None,
         object_list=None,
         boundaries_list=None,
         excitation_list=None,
@@ -90,7 +90,7 @@ class Modeler3D(GeometryModeler, Primitives3D, object):
         component_name : str, optional
             Name of the component. The default is ``None``.
         variables_to_include : list, optional
-            List of variables to include. The default is ``[]``.
+            List of variables to include. The default is all variables.
         object_list : list, optional
             List of object names to export. The default is all object names.
         boundaries_list : list, optional
@@ -98,7 +98,7 @@ class Modeler3D(GeometryModeler, Primitives3D, object):
         excitation_list : list, optional
             List of Excitation names to export. The default is all excitations.
         included_cs : list, optional
-            List of Coordinate Systems to export. The default is all coordinate systems.
+            List of Coordinate Systems to export. The default is the ``reference_cs``.
         reference_cs : str, optional
             The Coordinate System reference. The default is ``"Global"``.
         is_encrypted : bool, optional
@@ -127,18 +127,21 @@ class Modeler3D(GeometryModeler, Primitives3D, object):
             Component outline. Value can either be ``BoundingBox`` or ``None``.
             The default is ``BoundingBox``.
         auxiliary_dict : bool or str, optional
-            Whether to export the auxiliary file containing information about defined datasets and Icepak monitor
-            objects. A destination file can be specified using a string.
+            Whether to export the auxiliary file containing information about defined
+            datasets and Icepak monitor objects. A destination file can be specified
+            using a string.
             The default is ``False``.
         monitor_objects : list, optional
-            List of monitor objects' names to export. The default is the names of all monitor objects. This argument is
-            relevant only if ``auxiliary_dict_file`` is not set to ``False``.
+            List of monitor objects' names to export. The default is the names of all
+            monitor objects. This argument is relevant only if ``auxiliary_dict_file``
+            is not set to ``False``.
         datasets : list, optional
-            List of dataset names to export. The default is all datasets. This argument is relevant only if
-            ``auxiliary_dict_file`` is not set to ``False``.
+            List of dataset names to export. The default is all datasets. This argument
+             is relevant only if ``auxiliary_dict_file`` is set to ``True``.
         native_components : list, optional
-            List of native_components names to export. The default is all native_components. This argument is relevant
-            only if ``auxiliary_dict_file`` is not set to ``False``.
+            List of native_components names to export. The default is all
+            native_components. This argument is relevant only if ``auxiliary_dict_file``
+            is set to ``True``.
 
         Returns
         -------
@@ -149,6 +152,8 @@ class Modeler3D(GeometryModeler, Primitives3D, object):
         ----------
         >>> oEditor.Create3DComponent
         """
+        if not variables_to_include:
+            variables_to_include = []
         if not component_name:
             component_name = self._app.design_name
         dt_string = datetime.datetime.now().strftime("%H:%M:%S %p %b %d, %Y")
@@ -221,12 +226,12 @@ class Modeler3D(GeometryModeler, Primitives3D, object):
         if included_cs:
             allcs = included_cs
         else:
-            allcs = self.oeditor.GetCoordinateSystems()
+            allcs = [reference_cs]
         arg.append("IncludedCS:="), arg.append(allcs)
         arg.append("ReferenceCS:="), arg.append(reference_cs)
         par_description = []
         variables = []
-        if variables_to_include:
+        if variables_to_include is not None:
             dependent_variables = []
 
             ind_variables = [i for i in self._app._variable_manager.independent_variable_names]
@@ -286,7 +291,13 @@ class Modeler3D(GeometryModeler, Primitives3D, object):
         if meshops:
             used_mesh_ops = []
             for mesh in range(0, len(meshops)):
-                if all(item in object_list for item in self._app.mesh.meshoperations[mesh].props["Objects"]):
+                mesh_comp = []
+                for item in self._app.mesh.meshoperations[mesh].props["Objects"]:
+                    if isinstance(item, str):
+                        mesh_comp.append(item)
+                    else:
+                        mesh_comp.append(self.modeler.objects[item].name)
+                if all(included_obj in objs for included_obj in mesh_comp):
                     used_mesh_ops.append(self._app.mesh.meshoperations[mesh].name)
             arg2.append("MeshOperations:="), arg2.append(used_mesh_ops)
         else:
@@ -385,8 +396,8 @@ class Modeler3D(GeometryModeler, Primitives3D, object):
 
         Returns
         -------
-        bool
-            ``True`` when successful, ``False`` when failed.
+        :class:`pyaedt.modeler.components_3d.UserDefinedComponent`
+            User-defined component object.
 
         References
         ----------
@@ -396,7 +407,7 @@ class Modeler3D(GeometryModeler, Primitives3D, object):
         if not variables_to_include:
             variables_to_include = []
         if not component_name:
-            component_name = self._app.design_name
+            component_name = generate_unique_name(self._app.design_name)
         dt_string = datetime.datetime.now().strftime("%H:%M:%S %p %b %d, %Y")
         arg = [
             "NAME:CreateData",
@@ -452,8 +463,8 @@ class Modeler3D(GeometryModeler, Primitives3D, object):
         variables = []
         if variables_to_include:
             dependent_variables = []
-            ind_variables = self._app._variable_manager.independent_variable_names
-            dep_variables = self._app._variable_manager.dependent_variable_names
+            ind_variables = [i for i in self._app._variable_manager.independent_variable_names]
+            dep_variables = [i for i in self._app._variable_manager.dependent_variable_names]
             for param in variables_to_include:
                 if self._app[param] in ind_variables:
                     variables.append(self._app[param])
@@ -507,13 +518,23 @@ class Modeler3D(GeometryModeler, Primitives3D, object):
         if meshops:
             used_mesh_ops = []
             for mesh in range(0, len(meshops)):
-                if all(item in object_list for item in self._app.mesh.meshoperations[mesh].props["Objects"]):
+                mesh_comp = []
+                for item in self._app.mesh.meshoperations[mesh].props["Objects"]:
+                    if isinstance(item, str):
+                        mesh_comp.append(item)
+                    else:
+                        mesh_comp.append(self.modeler.objects[item].name)
+                if all(included_obj in objs for included_obj in mesh_comp):
                     used_mesh_ops.append(self._app.mesh.meshoperations[mesh].name)
             arg2.append("MeshOperations:="), arg2.append(used_mesh_ops)
         else:
             arg2.append("MeshOperations:="), arg2.append(meshops)
         arg3 = ["NAME:ImageFile", "ImageFile:=", ""]
-        return _retry_ntimes(3, self.oeditor.ReplaceWith3DComponent, arg, arg2, arg3)
+        old_components = self.user_defined_component_names
+        _retry_ntimes(3, self.oeditor.ReplaceWith3DComponent, arg, arg2, arg3)
+        self.refresh_all_ids()
+        new_name = list(set(self.user_defined_component_names) - set(old_components))
+        return self.user_defined_components[new_name[0]]
 
     @pyaedt_function_handler()
     def create_coaxial(
