@@ -726,7 +726,7 @@ class Primitives3DLayout(object):
 
     @property
     def padstacks(self):
-        """Read all padstacks from HFSS 3D Layout.
+        """Read all definitions from HFSS 3D Layout.
 
         Returns
         -------
@@ -931,15 +931,15 @@ class Primitives3DLayout(object):
             arg.append("name:="), arg.append(name)
             arg.append("ReferencedPadstack:="), arg.append(padstack),
             arg.append("vposition:="),
-            arg.append(["x:=", self.arg_with_dim(x), "y:=", self.arg_with_dim(y)])
+            arg.append(["x:=", self.number_with_units(x), "y:=", self.number_with_units(y)])
             arg.append("vrotation:="), arg.append([str(rotation) + "deg"])
             if hole_diam:
                 arg.append("overrides hole:="), arg.append(True)
-                arg.append("hole diameter:="), arg.append([self.arg_with_dim(hole_diam)])
+                arg.append("hole diameter:="), arg.append([self.number_with_units(hole_diam)])
 
             else:
                 arg.append("overrides hole:="), arg.append(False)
-                arg.append("hole diameter:="), arg.append([self.arg_with_dim(1)])
+                arg.append("hole diameter:="), arg.append([self.number_with_units(1)])
 
             arg.append("Pin:="), arg.append(False)
             arg.append("highest_layer:="), arg.append(top_layer)
@@ -1012,9 +1012,9 @@ class Primitives3DLayout(object):
         vArg2.append("Name:="), vArg2.append(name)
         vArg2.append("LayerName:="), vArg2.append(layername)
         vArg2.append("lw:="), vArg2.append("0")
-        vArg2.append("x:="), vArg2.append(self.arg_with_dim(x))
-        vArg2.append("y:="), vArg2.append(self.arg_with_dim(y))
-        vArg2.append("r:="), vArg2.append(self.arg_with_dim(radius))
+        vArg2.append("x:="), vArg2.append(self.number_with_units(x))
+        vArg2.append("y:="), vArg2.append(self.number_with_units(y))
+        vArg2.append("r:="), vArg2.append(self.number_with_units(radius))
         vArg1.append(vArg2)
         self.oeditor.CreateCircle(vArg1)
         primitive = Circle3dLayout(self, name, False)
@@ -1077,12 +1077,17 @@ class Primitives3DLayout(object):
         vArg2.append("Name:="), vArg2.append(name)
         vArg2.append("LayerName:="), vArg2.append(layername)
         vArg2.append("lw:="), vArg2.append("0")
-        vArg2.append("Ax:="), vArg2.append(self.arg_with_dim(origin[0]))
-        vArg2.append("Ay:="), vArg2.append(self.arg_with_dim(origin[1]))
-        vArg2.append("Bx:="), vArg2.append(self.arg_with_dim(origin[0]) + "+" + self.arg_with_dim(dimensions[0]))
-        vArg2.append("By:="), vArg2.append(self.arg_with_dim(origin[1]) + "+" + self.arg_with_dim(dimensions[1]))
-        vArg2.append("cr:="), vArg2.append(self.arg_with_dim(corner_radius))
-        vArg2.append("ang="), vArg2.append(self.arg_with_dim(angle))
+        vArg2.append("Ax:="), vArg2.append(self.number_with_units(origin[0]))
+        vArg2.append("Ay:="), vArg2.append(self.number_with_units(origin[1]))
+        vArg2.append("Bx:="), vArg2.append(
+            self.number_with_units(origin[0]) + "+" + self.number_with_units(dimensions[0])
+        )
+        vArg2.append("By:="), vArg2.append(
+            self.number_with_units(origin[1]) + "+" + self.number_with_units(dimensions[1])
+        )
+        vArg2.append("cr:="), vArg2.append(self.number_with_units(corner_radius))
+        vArg2.append("ang:=")
+        vArg2.append(self.number_with_units(angle, "deg"))
         vArg1.append(vArg2)
         self.oeditor.CreateRectangle(vArg1)
         primitive = Rect3dLayout(self, name, False)
@@ -1265,7 +1270,7 @@ class Primitives3DLayout(object):
             "LayerName:=",
             layername,
             "lw:=",
-            self.arg_with_dim(lw),
+            self.number_with_units(lw),
             "endstyle:=",
             end_style,
             "StartCap:=",
@@ -1293,6 +1298,9 @@ class Primitives3DLayout(object):
     def arg_with_dim(self, Value, sUnits=None):
         """Format arguments with dimensions.
 
+        .. deprecated:: 0.6.56
+           Use :func:`number_with_units` instead.
+
         Parameters
         ----------
         Value :
@@ -1305,14 +1313,27 @@ class Primitives3DLayout(object):
         str
             String containing the value or value and the units if `sUnits` is not ``None``.
         """
-        if type(Value) is str:
-            val = Value
-        else:
-            if sUnits is None:
-                sUnits = self.model_units
-            val = "{0}{1}".format(Value, sUnits)
+        warnings.warn("Use :func:`number_with_units` instead.", DeprecationWarning)
+        return self._app.number_with_units(Value, sUnits)
 
-        return val
+    @pyaedt_function_handler()
+    def number_with_units(self, value, units=None):
+        """Convert a number to a string with units. If value is a string, it's returned as is.
+
+        Parameters
+        ----------
+        value : float, int, str
+            Input  number or string.
+        units : optional
+            Units for formatting. The default is ``None``, which uses ``"meter"``.
+
+        Returns
+        -------
+        str
+           String concatenating the value and unit.
+
+        """
+        return self._app.number_with_units(value, units)
 
     @pyaedt_function_handler
     def place_3d_component(
